summaryrefslogtreecommitdiff
path: root/src/pal
diff options
context:
space:
mode:
authorJan Kotas <jkotas@microsoft.com>2015-11-17 14:27:13 -0800
committerJan Kotas <jkotas@microsoft.com>2015-11-17 14:27:13 -0800
commit38721c11196ea8c19d3a8f315e5b6f0361a8c8f5 (patch)
tree95358f028a1b09dd889d0a8d56f774eec6fbd25a /src/pal
parenta2bd4c042f22210fb6257c662cddeb601512908b (diff)
parenta69cb6bda747a4cf55acbfcc4f87b933d9027e36 (diff)
downloadcoreclr-38721c11196ea8c19d3a8f315e5b6f0361a8c8f5.tar.gz
coreclr-38721c11196ea8c19d3a8f315e5b6f0361a8c8f5.tar.bz2
coreclr-38721c11196ea8c19d3a8f315e5b6f0361a8c8f5.zip
Merge pull request #2049 from stephentoub/uuid_generate_random
Use uuid_generate_random instead of uuid_generate in CoCreateGuid
Diffstat (limited to 'src/pal')
-rw-r--r--src/pal/src/misc/miscpalapi.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/pal/src/misc/miscpalapi.cpp b/src/pal/src/misc/miscpalapi.cpp
index d225071851..15cb741684 100644
--- a/src/pal/src/misc/miscpalapi.cpp
+++ b/src/pal/src/misc/miscpalapi.cpp
@@ -353,10 +353,10 @@ PALAPI
CoCreateGuid(OUT GUID * pguid)
{
#if HAVE_LIBUUID_H
- uuid_generate(*(uuid_t*)pguid);
+ uuid_generate_random(*(uuid_t*)pguid);
- // Change the byte order of the Data1, 2 and 3, since the uuid_generate generates them
- // with big endian while GUIDS need to have them in little endian.
+ // Change the byte order of the Data1, 2 and 3, since the uuid_generate_random
+ // generates them with big endian while GUIDS need to have them in little endian.
pguid->Data1 = SWAP32(pguid->Data1);
pguid->Data2 = SWAP16(pguid->Data2);
pguid->Data3 = SWAP16(pguid->Data3);